// rfconfig.js - defines RF front-end config and channels
//=========================================

module.exports = {
	getBandParams: function(bandId) {
		return bandParams[bandId];
	},
  getDuration: function(bandId) {
    return DURATIONS[bandId];
  },
  getAntenna: function(antennaId) {
    return ANTENNAS[antennaId];
  },
  getGain: function(bandId) {
    return GAINS[bandId];
  },
  getConfig: function() {
    var config = {
      "durations": DURATIONS,
      "antennas": ANTENNAS,
      "gains": GAINS,
      "bandChannels": BAND_CHANNELS,
      "channelParams": CHANNEL_PARAMS,
    };
    return config;
  },
}

/* Desired duration of sample for each band (in seconds) */
const DURATIONS = {
  "fm": 2,
  "dvb": 2,
  "egsm900d": 2,
  "gsm1800d": 2,
  "wifi24": 2,
  "wifi50": 2,
};

/* Defines the mapping of antennas to SDR frontends. */
const ANTENNAS = {
  "vert2450": {"subdev": "A:A", "ant":"TX/RX"},
  "vert900": {"subdev": "A:A", "ant":"RX2"},
  "vert144": {"subdev": "A:B", "ant":"RX2"},
};

/* RF front-end gain for each band. */
const GAINS = {
  "fm": 40,
  "dvb": 40,
  "egsm900d": 40,
  "gsm1800d": 40,
  "wifi24": 40,
  "wifi50": 40,
};

/* Parameters of RF bands. */
const BAND_CHANNELS = {
  "fm":   ["fm"],
  "dvb": ["dvb-ch24","dvb-ch27","dvb-ch31","dvb-ch34","dvb-ch36","dvb-ch37",], // channels available in Luxembourg
  "egsm900d": ["egsm900d-1", "egsm900d-2"], // eGSM-900 downlink (925.0–960.0), split in two overlapping 20 MHz halves
  "gsm1800d": ["gsm1800d-1", "gsm1800d-2", "gsm1800d-3"], // GSM-1800 downlink (1805.2–1879.8), split into three 25 MHz wide parts
  
  // ******* EMEA regulations *******
  "wifi24": ["wifi24-ch01","wifi24-ch02","wifi24-ch03","wifi24-ch04","wifi24-ch05",
             "wifi24-ch06","wifi24-ch07","wifi24-ch08","wifi24-ch09","wifi24-ch10",
             "wifi24-ch11","wifi24-ch12","wifi24-ch13"],
  "wifi50": ["wifi50-ch36","wifi50-ch40","wifi50-ch44","wifi50-ch48",
             "wifi50-ch52","wifi50-ch56","wifi50-ch60","wifi50-ch64",
             "wifi50-ch100","wifi50-ch104","wifi50-ch108","wifi50-ch112",
             "wifi50-ch116","wifi50-ch120","wifi50-ch124","wifi50-ch128",
             "wifi50-ch132","wifi50-ch136","wifi50-ch140"],
/*  "dvb":  [ // In EMEA, there are no channels 1-4 and 13-21
           "dvb-ch05","dvb-ch06","dvb-ch07","dvb-ch08","dvb-ch09",
           "dvb-ch10","dvb-ch11","dvb-ch12",
                      "dvb-ch21","dvb-ch22","dvb-ch23","dvb-ch24",
           "dvb-ch25","dvb-ch26","dvb-ch27","dvb-ch28","dvb-ch29",
           "dvb-ch30","dvb-ch31","dvb-ch32","dvb-ch33","dvb-ch34",
           "dvb-ch35","dvb-ch36","dvb-ch37","dvb-ch38","dvb-ch39",
           "dvb-ch40","dvb-ch41","dvb-ch42","dvb-ch43","dvb-ch44",
           "dvb-ch45","dvb-ch46","dvb-ch47","dvb-ch48","dvb-ch49",
           "dvb-ch50","dvb-ch51","dvb-ch52","dvb-ch53","dvb-ch54",
           "dvb-ch55","dvb-ch56","dvb-ch57","dvb-ch58","dvb-ch59",
           "dvb-ch60","dvb-ch61","dvb-ch62","dvb-ch63","dvb-ch64",
           "dvb-ch65","dvb-ch66","dvb-ch67","dvb-ch68","dvb-ch69"],
*/

  // ******* US regulations *******
/*
  "wifi24": ["wifi24-ch01","wifi24-ch02","wifi24-ch03","wifi24-ch04","wifi24-ch05",
             "wifi24-ch06","wifi24-ch07","wifi24-ch08","wifi24-ch09","wifi24-ch10",
             "wifi24-ch11"],
  "wifi50": ["wifi50-ch36","wifi50-ch40","wifi50-ch44","wifi50-ch48",
             "wifi50-ch52","wifi50-ch56","wifi50-ch60","wifi50-ch64",
             "wifi50-ch149","wifi50-ch153","wifi50-ch157","wifi50-ch161",
             "wifi50-ch165"],
*/
};

/* Parameters of each channel. */
const CHANNEL_PARAMS = {
  "fm": {
    "name": "Commercial FM radio (87.5-108 MHz)",
    "centerFreq": 98e6, 
    "rate": 21e6,
    "bandwidth": 21e6,
    "antenna": "vert144",
  }, 
  "egsm900d-1": {
    "name": "EGSM 900 downlink (925-960 MHz) (Part 1: 925-945 MHz)",
    "centerFreq": 935e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert900",
  },
  "egsm900d-2": {
    "name": "EGSM 900 downlink (925-960 MHz) (Part 2: 940-960 MHz)",
    "centerFreq": 950e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert900",
  },
  "gsm1800d-1": {
    "name": "GSM-1800 downlink (1805.2–1879.8 MHz) (Part 1: 1805-1830 MHz)",
    "centerFreq": 1817.5e6,
    "rate": 25e6,
    "bandwidth": 25e6,
    "antenna": "vert900",
  },
  "gsm1800d-2": {
    "name": "GSM-1800 downlink (1805.2–1879.8 MHz) (Part 2: 1830-1855 MHz)",
    "centerFreq": 1842.5e6,
    "rate": 25e6,
    "bandwidth": 25e6,
    "antenna": "vert900",
  },
  "gsm1800d-3": {
    "name": "GSM-1800 downlink (1805.2–1879.8 MHz) (Part 3: 1855-1880 MHz)",
    "centerFreq": 1867.5e6,
    "rate": 25e6,
    "bandwidth": 25e6,
    "antenna": "vert900",
  },
  // DVB channels 1 to 4 are not used
  "dvb-ch5": {
    "name": "DVB ch5 177.5 MHz",
    "centerFreq": 177.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch6": {
    "name": "DVB ch6 184.5 MHz",
    "centerFreq": 184.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch7": {
    "name": "DVB ch7 191.5 MHz",
    "centerFreq": 191.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch8": {
    "name": "DVB ch8 198.5 MHz",
    "centerFreq": 198.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch9": {
    "name": "DVB ch9 205.5 MHz",
    "centerFreq": 205.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch10": {
    "name": "DVB ch10 212.5 MHz",
    "centerFreq": 212.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch11": {
    "name": "DVB ch11 219.5 MHz",
    "centerFreq": 219.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch12": {
    "name": "DVB ch12 226.5 MHz",
    "centerFreq": 226.5e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  // Channels 13 to 22 are not used
  "dvb-ch21": {
    "name": "DVB ch21 474 MHz",
    "centerFreq": 474e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch22": {
    "name": "DVB ch22 482 MHz",
    "centerFreq": 482e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch23": {
    "name": "DVB ch23 490 MHz",
    "centerFreq": 490e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch24": {
    "name": "DVB ch24 498 MHz",
    "centerFreq": 498e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch25": {
    "name": "DVB ch25 506 MHz",
    "centerFreq": 506e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch26": {
    "name": "DVB ch26 514 MHz",
    "centerFreq": 514e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch27": {
    "name": "DVB ch27 522 MHz",
    "centerFreq": 522e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch28": {
    "name": "DVB ch28 530 MHz",
    "centerFreq": 530e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch29": {
    "name": "DVB ch29 538 MHz",
    "centerFreq": 538e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch30": {
    "name": "DVB ch30 546 MHz",
    "centerFreq": 546e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch31": {
    "name": "DVB ch31 554 MHz",
    "centerFreq": 554e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch32": {
    "name": "DVB ch32 562 MHz",
    "centerFreq": 562e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch33": {
    "name": "DVB ch33 570 MHz",
    "centerFreq": 570e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch34": {
    "name": "DVB ch34 578 MHz",
    "centerFreq": 578e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch35": {
    "name": "DVB ch35 586 MHz",
    "centerFreq": 586e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch36": {
    "name": "DVB ch36 594 MHz",
    "centerFreq": 594e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch37": {
    "name": "DVB ch37 602 MHz",
    "centerFreq": 602e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch38": {
    "name": "DVB ch38 610 MHz",
    "centerFreq": 610e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch39": {
    "name": "DVB ch39 618 MHz",
    "centerFreq": 618e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch40": {
    "name": "DVB ch40 626 MHz",
    "centerFreq": 626e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch41": {
    "name": "DVB ch41 634 MHz",
    "centerFreq": 634e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch42": {
    "name": "DVB ch42 642 MHz",
    "centerFreq": 642e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch43": {
    "name": "DVB ch43 650 MHz",
    "centerFreq": 650e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch44": {
    "name": "DVB ch44 658 MHz",
    "centerFreq": 658e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch45": {
    "name": "DVB ch45 666 MHz",
    "centerFreq": 666e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch46": {
    "name": "DVB ch46 674 MHz",
    "centerFreq": 674e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch47": {
    "name": "DVB ch47 682 MHz",
    "centerFreq": 682e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch48": {
    "name": "DVB ch48 690 MHz",
    "centerFreq": 690e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch49": {
    "name": "DVB ch49 698 MHz",
    "centerFreq": 698e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch50": {
    "name": "DVB ch50 706 MHz",
    "centerFreq": 706e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch51": {
    "name": "DVB ch51 714 MHz",
    "centerFreq": 714e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch52": {
    "name": "DVB ch52 722 MHz",
    "centerFreq": 722e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch53": {
    "name": "DVB ch53 730 MHz",
    "centerFreq": 730e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch54": {
    "name": "DVB ch54 738 MHz",
    "centerFreq": 738e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch55": {
    "name": "DVB ch55 746 MHz",
    "centerFreq": 746e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch56": {
    "name": "DVB ch56 754 MHz",
    "centerFreq": 754e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch57": {
    "name": "DVB ch57 762 MHz",
    "centerFreq": 762e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch58": {
    "name": "DVB ch58 770 MHz",
    "centerFreq": 770e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch59": {
    "name": "DVB ch59 778 MHz",
    "centerFreq": 778e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch60": {
    "name": "DVB ch60 786 MHz",
    "centerFreq": 786e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch61": {
    "name": "DVB ch61 794 MHz",
    "centerFreq": 794e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch62": {
    "name": "DVB ch62 802 MHz",
    "centerFreq": 802e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch63": {
    "name": "DVB ch63 810 MHz",
    "centerFreq": 810e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch64": {
    "name": "DVB ch64 818 MHz",
    "centerFreq": 818e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch65": {
    "name": "DVB ch65 826 MHz",
    "centerFreq": 826e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch66": {
    "name": "DVB ch66 834 MHz",
    "centerFreq": 834e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch67": {
    "name": "DVB ch67 842 MHz",
    "centerFreq": 842e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch68": {
    "name": "DVB ch68 850 MHz",
    "centerFreq": 850e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  "dvb-ch69": {
    "name": "DVB ch69 858 MHz",
    "centerFreq": 858e6,
    "rate": (8/7)*8e6,
    "bandwidth": 8e6,
    "antenna": "vert144",
  },
  // wifi24 is 802.11g/n in 2.4 GHz band with 22 MHz wide channels 
  // Source: http://www.cisco.com/c/en/us/td/docs/routers/access/3200/software/wireless/3200WirelessConfigGuide/RadioChannelFrequencies.pdf
  "wifi24-ch01": {
    "name": "Wi-Fi 2.4GHz Ch1 (2412 MHz)",
    "centerFreq": 2412e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch02": {
    "name": "Wi-Fi 2.4 GHz Ch2 (2417 MHz)",
    "centerFreq": 2417e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch03": {
    "name": "Wi-Fi 2.4 GHz Ch3 (2422 MHz)",
    "centerFreq": 2422e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch04": {
    "name": "Wi-Fi 2.4 GHz Ch4 (2427 MHz)",
    "centerFreq": 2427e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch05": {
    "name": "Wi-Fi 2.4 GHz Ch5 (2432 MHz)",
    "centerFreq": 2432e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch06": {
    "name": "Wi-Fi 2.4 GHz Ch6 (2437 MHz)",
    "centerFreq": 2437e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch07": {
    "name": "Wi-Fi 2.4 GHz Ch7 (2442 MHz)",
    "centerFreq": 2442e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch08": {
    "name": "Wi-Fi 2.4 GHz Ch8 (2447 MHz)",
    "centerFreq": 2447e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch09": {
    "name": "Wi-Fi 2.4 GHz Ch9 (2452 MHz)",
    "centerFreq": 2452e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch10": {
    "name": "Wi-Fi 2.4 GHz Ch10 (2457 MHz)",
    "centerFreq": 2457e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch11": {
    "name": "Wi-Fi 2.4 GHz Ch11 (2462 MHz)",
    "centerFreq": 2462e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch12": {
    "name": "Wi-Fi 2.4 GHz Ch12 (2467 MHz)",
    "centerFreq": 2467e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  "wifi24-ch13": {
    "name": "Wi-Fi 2.4 GHz Ch13 (2472 MHz)",
    "centerFreq": 2472e6,
    "rate": 22e6,
    "bandwidth": 22e6,
    "antenna": "vert2450",
  },
  // wifi50 is 802.11a/n in 5 GHz band with 20 MHz wide channels 
  // Source: http://www.cisco.com/c/en/us/td/docs/routers/access/3200/software/wireless/3200WirelessConfigGuide/RadioChannelFrequencies.pdf
  // (Tables 2 and 5)
  "wifi50-ch36": {
    "name": "Wi-Fi 5 GHz Ch36 (5180 MHz)",
    "centerFreq": 5180e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch40": {
    "name": "Wi-Fi 5 GHz Ch40 (5200 MHz)",
    "centerFreq": 5200e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch44": {
    "name": "Wi-Fi 5 GHz Ch44 (5220 MHz)",
    "centerFreq": 5220e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch48": {
    "name": "Wi-Fi 5 GHz Ch48 (5240 MHz)",
    "centerFreq": 5240e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch52": {
    "name": "Wi-Fi 5 GHz Ch52 (5260 MHz)",
    "centerFreq": 5260e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch56": {
    "name": "Wi-Fi 5 GHz Ch56 (5280 MHz)",
    "centerFreq": 5280e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch60": {
    "name": "Wi-Fi 5 GHz Ch60 (5300 MHz)",
    "centerFreq": 5300e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch64": {
    "name": "Wi-Fi 5 GHz Ch64 (5320 MHz)",
    "centerFreq": 5320e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch100": {
    "name": "Wi-Fi 5 GHz Ch100 (5500 MHz)",
    "centerFreq": 5500e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch104": {
    "name": "Wi-Fi 5 GHz Ch104 (5520 MHz)",
    "centerFreq": 5520e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch108": {
    "name": "Wi-Fi 5 GHz Ch108 (5540 MHz)",
    "centerFreq": 5540e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch112": {
    "name": "Wi-Fi 5 GHz Ch112 (5560 MHz)",
    "centerFreq": 5560e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch116": {
    "name": "Wi-Fi 5 GHz Ch116 (5580 MHz)",
    "centerFreq": 5580e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch120": {
    "name": "Wi-Fi 5 GHz Ch120 (5600 MHz)",
    "centerFreq": 5600e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch124": {
    "name": "Wi-Fi 5 GHz Ch124 (5620 MHz)",
    "centerFreq": 5620e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch128": {
    "name": "Wi-Fi 5 GHz Ch128 (5640 MHz)",
    "centerFreq": 5640e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch132": {
    "name": "Wi-Fi 5 GHz Ch132 (5660 MHz)",
    "centerFreq": 5660e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch136": {
    "name": "Wi-Fi 5 GHz Ch136 (5680 MHz)",
    "centerFreq": 5680e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch140": {
    "name": "Wi-Fi 5 GHz Ch140 (5700 MHz)",
    "centerFreq": 5700e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch149": {
    "name": "Wi-Fi 5 GHz Ch149 (5745 MHz)",
    "centerFreq": 5745e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch153": {
    "name": "Wi-Fi 5 GHz Ch153 (5765 MHz)",
    "centerFreq": 5765e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch157": {
    "name": "Wi-Fi 5 GHz Ch157 (5785 MHz)",
    "centerFreq": 5785e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch161": {
    "name": "Wi-Fi 5 GHz Ch161 (5805 MHz)",
    "centerFreq": 5805e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
  "wifi50-ch165": {
    "name": "Wi-Fi 5 GHz Ch165 (5809 MHz)",
    "centerFreq": 5809e6,
    "rate": 20e6,
    "bandwidth": 20e6,
    "antenna": "vert2450",
  },
};

var bandParams = {};
for (var bandId in BAND_CHANNELS) {
  bandParams[bandId] = [];
  var bandChannels = BAND_CHANNELS[bandId];
  if (!bandChannels) {
    // an extra check to prevent typos
    console.log("ERROR: Undefined channels for band: " + bandId);
  }

  for (var iChannelId in bandChannels) {
    var channelId = bandChannels[iChannelId];
    var channelParams = CHANNEL_PARAMS[channelId];
    if (!channelParams) {
      // an extra check to prevent typos
      console.log("ERROR: undefined params for channel " + channelId);
    }
    channelParams.id = channelId;
    bandParams[bandId].push(channelParams);
  }
}
